# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetCommandsResult',
    'AwaitableGetCommandsResult',
    'get_commands',
    'get_commands_output',
]

@pulumi.output_type
class GetCommandsResult:
    """
    A collection of values returned by getCommands.
    """
    def __init__(__self__, command_type=None, commands=None, content_encoding=None, desktop_id=None, id=None, ids=None, output_file=None, status=None):
        if command_type and not isinstance(command_type, str):
            raise TypeError("Expected argument 'command_type' to be a str")
        pulumi.set(__self__, "command_type", command_type)
        if commands and not isinstance(commands, list):
            raise TypeError("Expected argument 'commands' to be a list")
        pulumi.set(__self__, "commands", commands)
        if content_encoding and not isinstance(content_encoding, str):
            raise TypeError("Expected argument 'content_encoding' to be a str")
        pulumi.set(__self__, "content_encoding", content_encoding)
        if desktop_id and not isinstance(desktop_id, str):
            raise TypeError("Expected argument 'desktop_id' to be a str")
        pulumi.set(__self__, "desktop_id", desktop_id)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="commandType")
    def command_type(self) -> Optional[str]:
        return pulumi.get(self, "command_type")

    @property
    @pulumi.getter
    def commands(self) -> Sequence['outputs.GetCommandsCommandResult']:
        return pulumi.get(self, "commands")

    @property
    @pulumi.getter(name="contentEncoding")
    def content_encoding(self) -> Optional[str]:
        return pulumi.get(self, "content_encoding")

    @property
    @pulumi.getter(name="desktopId")
    def desktop_id(self) -> Optional[str]:
        return pulumi.get(self, "desktop_id")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")


class AwaitableGetCommandsResult(GetCommandsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetCommandsResult(
            command_type=self.command_type,
            commands=self.commands,
            content_encoding=self.content_encoding,
            desktop_id=self.desktop_id,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            status=self.status)


def get_commands(command_type: Optional[str] = None,
                 content_encoding: Optional[str] = None,
                 desktop_id: Optional[str] = None,
                 ids: Optional[Sequence[str]] = None,
                 output_file: Optional[str] = None,
                 status: Optional[str] = None,
                 opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetCommandsResult:
    """
    This data source provides the Ecd Commands of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.146.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default_simple_office_site = alicloud.eds.SimpleOfficeSite("default",
        cidr_block="172.16.0.0/12",
        desktop_access_type="Internet",
        office_site_name="your_office_site_name")
    default = alicloud.eds.get_bundles(bundle_type="SYSTEM",
        name_regex="windows")
    default_ecd_policy_group = alicloud.eds.EcdPolicyGroup("default",
        policy_group_name="your_policy_group_name",
        clipboard="readwrite",
        local_drive="read",
        authorize_access_policy_rules=[{
            "description": "example_value",
            "cidr_ip": "1.2.3.4/24",
        }],
        authorize_security_policy_rules=[{
            "type": "inflow",
            "policy": "accept",
            "description": "example_value",
            "port_range": "80/80",
            "ip_protocol": "TCP",
            "priority": "1",
            "cidr_ip": "0.0.0.0/0",
        }])
    default_desktop = alicloud.eds.Desktop("default",
        office_site_id=default_simple_office_site.id,
        policy_group_id=default_ecd_policy_group.id,
        bundle_id=default.bundles[0].id,
        desktop_name=name)
    default_command = alicloud.eds.Command("default",
        command_content="ipconfig",
        command_type="RunPowerShellScript",
        desktop_id=default_desktop.id)
    ids = alicloud.eds.get_commands()
    pulumi.export("ecdCommandId1", ids.commands[0].id)
    ```


    :param str command_type: The Script Type. Valid values: `RunBatScript`, `RunPowerShellScript`.
    :param str content_encoding: That Returns the Data Encoding Method. Valid values: `Base64`, `PlainText`.
    :param str desktop_id: The desktop id of the Desktop.
    :param Sequence[str] ids: A list of Command IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: Script Is Executed in the Overall Implementation of the State. Valid values: `Pending`, `Failed`, `PartialFailed`, `Running`, `Stopped`, `Stopping`, `Finished`, `Success`.
    """
    __args__ = dict()
    __args__['commandType'] = command_type
    __args__['contentEncoding'] = content_encoding
    __args__['desktopId'] = desktop_id
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:eds/getCommands:getCommands', __args__, opts=opts, typ=GetCommandsResult).value

    return AwaitableGetCommandsResult(
        command_type=pulumi.get(__ret__, 'command_type'),
        commands=pulumi.get(__ret__, 'commands'),
        content_encoding=pulumi.get(__ret__, 'content_encoding'),
        desktop_id=pulumi.get(__ret__, 'desktop_id'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        status=pulumi.get(__ret__, 'status'))
def get_commands_output(command_type: Optional[pulumi.Input[Optional[str]]] = None,
                        content_encoding: Optional[pulumi.Input[Optional[str]]] = None,
                        desktop_id: Optional[pulumi.Input[Optional[str]]] = None,
                        ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                        output_file: Optional[pulumi.Input[Optional[str]]] = None,
                        status: Optional[pulumi.Input[Optional[str]]] = None,
                        opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetCommandsResult]:
    """
    This data source provides the Ecd Commands of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.146.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default_simple_office_site = alicloud.eds.SimpleOfficeSite("default",
        cidr_block="172.16.0.0/12",
        desktop_access_type="Internet",
        office_site_name="your_office_site_name")
    default = alicloud.eds.get_bundles(bundle_type="SYSTEM",
        name_regex="windows")
    default_ecd_policy_group = alicloud.eds.EcdPolicyGroup("default",
        policy_group_name="your_policy_group_name",
        clipboard="readwrite",
        local_drive="read",
        authorize_access_policy_rules=[{
            "description": "example_value",
            "cidr_ip": "1.2.3.4/24",
        }],
        authorize_security_policy_rules=[{
            "type": "inflow",
            "policy": "accept",
            "description": "example_value",
            "port_range": "80/80",
            "ip_protocol": "TCP",
            "priority": "1",
            "cidr_ip": "0.0.0.0/0",
        }])
    default_desktop = alicloud.eds.Desktop("default",
        office_site_id=default_simple_office_site.id,
        policy_group_id=default_ecd_policy_group.id,
        bundle_id=default.bundles[0].id,
        desktop_name=name)
    default_command = alicloud.eds.Command("default",
        command_content="ipconfig",
        command_type="RunPowerShellScript",
        desktop_id=default_desktop.id)
    ids = alicloud.eds.get_commands()
    pulumi.export("ecdCommandId1", ids.commands[0].id)
    ```


    :param str command_type: The Script Type. Valid values: `RunBatScript`, `RunPowerShellScript`.
    :param str content_encoding: That Returns the Data Encoding Method. Valid values: `Base64`, `PlainText`.
    :param str desktop_id: The desktop id of the Desktop.
    :param Sequence[str] ids: A list of Command IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str status: Script Is Executed in the Overall Implementation of the State. Valid values: `Pending`, `Failed`, `PartialFailed`, `Running`, `Stopped`, `Stopping`, `Finished`, `Success`.
    """
    __args__ = dict()
    __args__['commandType'] = command_type
    __args__['contentEncoding'] = content_encoding
    __args__['desktopId'] = desktop_id
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['status'] = status
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:eds/getCommands:getCommands', __args__, opts=opts, typ=GetCommandsResult)
    return __ret__.apply(lambda __response__: GetCommandsResult(
        command_type=pulumi.get(__response__, 'command_type'),
        commands=pulumi.get(__response__, 'commands'),
        content_encoding=pulumi.get(__response__, 'content_encoding'),
        desktop_id=pulumi.get(__response__, 'desktop_id'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        status=pulumi.get(__response__, 'status')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['RoleArgs', 'Role']

@pulumi.input_type
class RoleArgs:
    def __init__(__self__, *,
                 assume_role_policy_document: pulumi.Input[str],
                 role_name: pulumi.Input[str],
                 description: Optional[pulumi.Input[str]] = None,
                 max_session_duration: Optional[pulumi.Input[int]] = None):
        """
        The set of arguments for constructing a Role resource.
        :param pulumi.Input[str] assume_role_policy_document: The content of the permissions strategy that plays a role.
        :param pulumi.Input[str] role_name: Role Name. The length is 1 ~ 64 characters, which can include English letters, numbers, dots "." and dashes "-".
        :param pulumi.Input[str] description: The description of the Resource Manager role.
        :param pulumi.Input[int] max_session_duration: Role maximum session time. Valid values: [3600-43200]. Default to `3600`.
        """
        pulumi.set(__self__, "assume_role_policy_document", assume_role_policy_document)
        pulumi.set(__self__, "role_name", role_name)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if max_session_duration is not None:
            pulumi.set(__self__, "max_session_duration", max_session_duration)

    @property
    @pulumi.getter(name="assumeRolePolicyDocument")
    def assume_role_policy_document(self) -> pulumi.Input[str]:
        """
        The content of the permissions strategy that plays a role.
        """
        return pulumi.get(self, "assume_role_policy_document")

    @assume_role_policy_document.setter
    def assume_role_policy_document(self, value: pulumi.Input[str]):
        pulumi.set(self, "assume_role_policy_document", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Input[str]:
        """
        Role Name. The length is 1 ~ 64 characters, which can include English letters, numbers, dots "." and dashes "-".
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the Resource Manager role.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="maxSessionDuration")
    def max_session_duration(self) -> Optional[pulumi.Input[int]]:
        """
        Role maximum session time. Valid values: [3600-43200]. Default to `3600`.
        """
        return pulumi.get(self, "max_session_duration")

    @max_session_duration.setter
    def max_session_duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_session_duration", value)


@pulumi.input_type
class _RoleState:
    def __init__(__self__, *,
                 arn: Optional[pulumi.Input[str]] = None,
                 assume_role_policy_document: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 max_session_duration: Optional[pulumi.Input[int]] = None,
                 role_id: Optional[pulumi.Input[str]] = None,
                 role_name: Optional[pulumi.Input[str]] = None,
                 update_date: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Role resources.
        :param pulumi.Input[str] arn: The resource descriptor of the role.
        :param pulumi.Input[str] assume_role_policy_document: The content of the permissions strategy that plays a role.
        :param pulumi.Input[str] description: The description of the Resource Manager role.
        :param pulumi.Input[int] max_session_duration: Role maximum session time. Valid values: [3600-43200]. Default to `3600`.
        :param pulumi.Input[str] role_id: This ID of Resource Manager role. The value is set to `role_name`.
        :param pulumi.Input[str] role_name: Role Name. The length is 1 ~ 64 characters, which can include English letters, numbers, dots "." and dashes "-".
        :param pulumi.Input[str] update_date: Role update time.
        """
        if arn is not None:
            pulumi.set(__self__, "arn", arn)
        if assume_role_policy_document is not None:
            pulumi.set(__self__, "assume_role_policy_document", assume_role_policy_document)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if max_session_duration is not None:
            pulumi.set(__self__, "max_session_duration", max_session_duration)
        if role_id is not None:
            pulumi.set(__self__, "role_id", role_id)
        if role_name is not None:
            pulumi.set(__self__, "role_name", role_name)
        if update_date is not None:
            pulumi.set(__self__, "update_date", update_date)

    @property
    @pulumi.getter
    def arn(self) -> Optional[pulumi.Input[str]]:
        """
        The resource descriptor of the role.
        """
        return pulumi.get(self, "arn")

    @arn.setter
    def arn(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "arn", value)

    @property
    @pulumi.getter(name="assumeRolePolicyDocument")
    def assume_role_policy_document(self) -> Optional[pulumi.Input[str]]:
        """
        The content of the permissions strategy that plays a role.
        """
        return pulumi.get(self, "assume_role_policy_document")

    @assume_role_policy_document.setter
    def assume_role_policy_document(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "assume_role_policy_document", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the Resource Manager role.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="maxSessionDuration")
    def max_session_duration(self) -> Optional[pulumi.Input[int]]:
        """
        Role maximum session time. Valid values: [3600-43200]. Default to `3600`.
        """
        return pulumi.get(self, "max_session_duration")

    @max_session_duration.setter
    def max_session_duration(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_session_duration", value)

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> Optional[pulumi.Input[str]]:
        """
        This ID of Resource Manager role. The value is set to `role_name`.
        """
        return pulumi.get(self, "role_id")

    @role_id.setter
    def role_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_id", value)

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> Optional[pulumi.Input[str]]:
        """
        Role Name. The length is 1 ~ 64 characters, which can include English letters, numbers, dots "." and dashes "-".
        """
        return pulumi.get(self, "role_name")

    @role_name.setter
    def role_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "role_name", value)

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> Optional[pulumi.Input[str]]:
        """
        Role update time.
        """
        return pulumi.get(self, "update_date")

    @update_date.setter
    def update_date(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "update_date", value)


class Role(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 assume_role_policy_document: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 max_session_duration: Optional[pulumi.Input[int]] = None,
                 role_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Resource Manager role resource. Members are resource containers in the resource directory, which can physically isolate resources to form an independent resource grouping unit. You can create members in the resource folder to manage them in a unified manner.
        For information about Resource Manager role and how to use it, see [What is Resource Manager role](https://www.alibabacloud.com/help/en/doc-detail/111231.htm).

        > **NOTE:** Available since v1.82.0.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tfexample"
        default = alicloud.get_account()
        example = alicloud.resourcemanager.Role("example",
            role_name=name,
            assume_role_policy_document=f\"\"\"     {{
                  "Statement": [
                       {{
                            "Action": "sts:AssumeRole",
                            "Effect": "Allow",
                            "Principal": {{
                                "RAM":[
                                        "acs:ram::{default.id}:root"
                                ]
                            }}
                        }}
                  ],
                  "Version": "1"
             }}
        \"\"\")
        ```

        ## Import

        Resource Manager can be imported using the id or role_name, e.g.

        ```sh
        $ pulumi import alicloud:resourcemanager/role:Role example testrd
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] assume_role_policy_document: The content of the permissions strategy that plays a role.
        :param pulumi.Input[str] description: The description of the Resource Manager role.
        :param pulumi.Input[int] max_session_duration: Role maximum session time. Valid values: [3600-43200]. Default to `3600`.
        :param pulumi.Input[str] role_name: Role Name. The length is 1 ~ 64 characters, which can include English letters, numbers, dots "." and dashes "-".
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: RoleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Resource Manager role resource. Members are resource containers in the resource directory, which can physically isolate resources to form an independent resource grouping unit. You can create members in the resource folder to manage them in a unified manner.
        For information about Resource Manager role and how to use it, see [What is Resource Manager role](https://www.alibabacloud.com/help/en/doc-detail/111231.htm).

        > **NOTE:** Available since v1.82.0.

        ## Example Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "tfexample"
        default = alicloud.get_account()
        example = alicloud.resourcemanager.Role("example",
            role_name=name,
            assume_role_policy_document=f\"\"\"     {{
                  "Statement": [
                       {{
                            "Action": "sts:AssumeRole",
                            "Effect": "Allow",
                            "Principal": {{
                                "RAM":[
                                        "acs:ram::{default.id}:root"
                                ]
                            }}
                        }}
                  ],
                  "Version": "1"
             }}
        \"\"\")
        ```

        ## Import

        Resource Manager can be imported using the id or role_name, e.g.

        ```sh
        $ pulumi import alicloud:resourcemanager/role:Role example testrd
        ```

        :param str resource_name: The name of the resource.
        :param RoleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(RoleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 assume_role_policy_document: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 max_session_duration: Optional[pulumi.Input[int]] = None,
                 role_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = RoleArgs.__new__(RoleArgs)

            if assume_role_policy_document is None and not opts.urn:
                raise TypeError("Missing required property 'assume_role_policy_document'")
            __props__.__dict__["assume_role_policy_document"] = assume_role_policy_document
            __props__.__dict__["description"] = description
            __props__.__dict__["max_session_duration"] = max_session_duration
            if role_name is None and not opts.urn:
                raise TypeError("Missing required property 'role_name'")
            __props__.__dict__["role_name"] = role_name
            __props__.__dict__["arn"] = None
            __props__.__dict__["role_id"] = None
            __props__.__dict__["update_date"] = None
        super(Role, __self__).__init__(
            'alicloud:resourcemanager/role:Role',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            arn: Optional[pulumi.Input[str]] = None,
            assume_role_policy_document: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            max_session_duration: Optional[pulumi.Input[int]] = None,
            role_id: Optional[pulumi.Input[str]] = None,
            role_name: Optional[pulumi.Input[str]] = None,
            update_date: Optional[pulumi.Input[str]] = None) -> 'Role':
        """
        Get an existing Role resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] arn: The resource descriptor of the role.
        :param pulumi.Input[str] assume_role_policy_document: The content of the permissions strategy that plays a role.
        :param pulumi.Input[str] description: The description of the Resource Manager role.
        :param pulumi.Input[int] max_session_duration: Role maximum session time. Valid values: [3600-43200]. Default to `3600`.
        :param pulumi.Input[str] role_id: This ID of Resource Manager role. The value is set to `role_name`.
        :param pulumi.Input[str] role_name: Role Name. The length is 1 ~ 64 characters, which can include English letters, numbers, dots "." and dashes "-".
        :param pulumi.Input[str] update_date: Role update time.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _RoleState.__new__(_RoleState)

        __props__.__dict__["arn"] = arn
        __props__.__dict__["assume_role_policy_document"] = assume_role_policy_document
        __props__.__dict__["description"] = description
        __props__.__dict__["max_session_duration"] = max_session_duration
        __props__.__dict__["role_id"] = role_id
        __props__.__dict__["role_name"] = role_name
        __props__.__dict__["update_date"] = update_date
        return Role(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def arn(self) -> pulumi.Output[str]:
        """
        The resource descriptor of the role.
        """
        return pulumi.get(self, "arn")

    @property
    @pulumi.getter(name="assumeRolePolicyDocument")
    def assume_role_policy_document(self) -> pulumi.Output[str]:
        """
        The content of the permissions strategy that plays a role.
        """
        return pulumi.get(self, "assume_role_policy_document")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the Resource Manager role.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="maxSessionDuration")
    def max_session_duration(self) -> pulumi.Output[Optional[int]]:
        """
        Role maximum session time. Valid values: [3600-43200]. Default to `3600`.
        """
        return pulumi.get(self, "max_session_duration")

    @property
    @pulumi.getter(name="roleId")
    def role_id(self) -> pulumi.Output[str]:
        """
        This ID of Resource Manager role. The value is set to `role_name`.
        """
        return pulumi.get(self, "role_id")

    @property
    @pulumi.getter(name="roleName")
    def role_name(self) -> pulumi.Output[str]:
        """
        Role Name. The length is 1 ~ 64 characters, which can include English letters, numbers, dots "." and dashes "-".
        """
        return pulumi.get(self, "role_name")

    @property
    @pulumi.getter(name="updateDate")
    def update_date(self) -> pulumi.Output[str]:
        """
        Role update time.
        """
        return pulumi.get(self, "update_date")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'GetOrganizationsOrganizationResult',
]

@pulumi.output_type
class GetOrganizationsOrganizationResult(dict):
    def __init__(__self__, *,
                 id: str,
                 organization_id: str,
                 organization_name: str):
        """
        :param str id: The ID of the Organization.
        :param str organization_id: The first ID of the resource.
        :param str organization_name: Company name.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "organization_id", organization_id)
        pulumi.set(__self__, "organization_name", organization_name)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the Organization.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="organizationId")
    def organization_id(self) -> str:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "organization_id")

    @property
    @pulumi.getter(name="organizationName")
    def organization_name(self) -> str:
        """
        Company name.
        """
        return pulumi.get(self, "organization_name")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'ClusterBootstrapAction',
    'ClusterConfig',
    'ClusterHostGroup',
    'ClusterMetaStoreConf',
    'ClusterModifyClusterServiceConfig',
    'GetClustersClusterResult',
    'GetClustersClusterAccessInfoResult',
    'GetClustersClusterAccessInfoZkLinkResult',
    'GetClustersClusterBootstrapActionListResult',
    'GetClustersClusterHostGroupListResult',
    'GetClustersClusterHostGroupListNodeResult',
    'GetClustersClusterHostGroupListNodeDiskInfoResult',
    'GetClustersClusterHostPoolInfoResult',
    'GetClustersClusterRelateClusterInfoResult',
    'GetClustersClusterSoftwareInfoResult',
    'GetClustersClusterSoftwareInfoSoftwareResult',
    'GetDiskTypesTypeResult',
    'GetInstanceTypesTypeResult',
    'GetMainVersionsMainVersionResult',
]

@pulumi.output_type
class ClusterBootstrapAction(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "executionFailStrategy":
            suggest = "execution_fail_strategy"
        elif key == "executionMoment":
            suggest = "execution_moment"
        elif key == "executionTarget":
            suggest = "execution_target"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ClusterBootstrapAction. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ClusterBootstrapAction.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ClusterBootstrapAction.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 arg: Optional[str] = None,
                 execution_fail_strategy: Optional[str] = None,
                 execution_moment: Optional[str] = None,
                 execution_target: Optional[str] = None,
                 name: Optional[str] = None,
                 path: Optional[str] = None):
        """
        :param str arg: bootstrap action args, e.g. "--a=b".
        :param str execution_fail_strategy: bootstrap action execution fail strategy, ’FAILED_BLOCKED’ or ‘FAILED_CONTINUE’ . Default value: "FAILED_BLOCKED
        :param str execution_moment: bootstrap action execution moment, ’BEFORE_INSTALL’ or ‘AFTER_STARTED’ . Default value: "BEFORE_INSTALL".
        :param str execution_target: bootstrap action execution target, you can specify the host group name, e.g. "core_group". If this is not specified, the bootstrap action execution target is whole cluster.
        :param str name: The name of emr cluster. The name length must be less than 64. Supported characters: chinese character, english character, number, "-", "_".
        :param str path: bootstrap action path, e.g. "oss://bucket/path".
        """
        if arg is not None:
            pulumi.set(__self__, "arg", arg)
        if execution_fail_strategy is not None:
            pulumi.set(__self__, "execution_fail_strategy", execution_fail_strategy)
        if execution_moment is not None:
            pulumi.set(__self__, "execution_moment", execution_moment)
        if execution_target is not None:
            pulumi.set(__self__, "execution_target", execution_target)
        if name is not None:
            pulumi.set(__self__, "name", name)
        if path is not None:
            pulumi.set(__self__, "path", path)

    @property
    @pulumi.getter
    def arg(self) -> Optional[str]:
        """
        bootstrap action args, e.g. "--a=b".
        """
        return pulumi.get(self, "arg")

    @property
    @pulumi.getter(name="executionFailStrategy")
    def execution_fail_strategy(self) -> Optional[str]:
        """
        bootstrap action execution fail strategy, ’FAILED_BLOCKED’ or ‘FAILED_CONTINUE’ . Default value: "FAILED_BLOCKED
        """
        return pulumi.get(self, "execution_fail_strategy")

    @property
    @pulumi.getter(name="executionMoment")
    def execution_moment(self) -> Optional[str]:
        """
        bootstrap action execution moment, ’BEFORE_INSTALL’ or ‘AFTER_STARTED’ . Default value: "BEFORE_INSTALL".
        """
        return pulumi.get(self, "execution_moment")

    @property
    @pulumi.getter(name="executionTarget")
    def execution_target(self) -> Optional[str]:
        """
        bootstrap action execution target, you can specify the host group name, e.g. "core_group". If this is not specified, the bootstrap action execution target is whole cluster.
        """
        return pulumi.get(self, "execution_target")

    @property
    @pulumi.getter
    def name(self) -> Optional[str]:
        """
        The name of emr cluster. The name length must be less than 64. Supported characters: chinese character, english character, number, "-", "_".
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def path(self) -> Optional[str]:
        """
        bootstrap action path, e.g. "oss://bucket/path".
        """
        return pulumi.get(self, "path")


@pulumi.output_type
class ClusterConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "configKey":
            suggest = "config_key"
        elif key == "configValue":
            suggest = "config_value"
        elif key == "fileName":
            suggest = "file_name"
        elif key == "serviceName":
            suggest = "service_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ClusterConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ClusterConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ClusterConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 config_key: str,
                 config_value: str,
                 file_name: str,
                 service_name: str):
        """
        :param str config_key: Custom configuration service config key, e.g. ’dfs.replication’.
        :param str config_value: Custom configuration service config value, e.g. ’3’.
        :param str file_name: Custom configuration service file name, e.g. ’hdfs-site’.
        """
        pulumi.set(__self__, "config_key", config_key)
        pulumi.set(__self__, "config_value", config_value)
        pulumi.set(__self__, "file_name", file_name)
        pulumi.set(__self__, "service_name", service_name)

    @property
    @pulumi.getter(name="configKey")
    def config_key(self) -> str:
        """
        Custom configuration service config key, e.g. ’dfs.replication’.
        """
        return pulumi.get(self, "config_key")

    @property
    @pulumi.getter(name="configValue")
    def config_value(self) -> str:
        """
        Custom configuration service config value, e.g. ’3’.
        """
        return pulumi.get(self, "config_value")

    @property
    @pulumi.getter(name="fileName")
    def file_name(self) -> str:
        """
        Custom configuration service file name, e.g. ’hdfs-site’.
        """
        return pulumi.get(self, "file_name")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> str:
        return pulumi.get(self, "service_name")


@pulumi.output_type
class ClusterHostGroup(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "autoRenew":
            suggest = "auto_renew"
        elif key == "chargeType":
            suggest = "charge_type"
        elif key == "decommissionTimeout":
            suggest = "decommission_timeout"
        elif key == "diskCapacity":
            suggest = "disk_capacity"
        elif key == "diskCount":
            suggest = "disk_count"
        elif key == "diskType":
            suggest = "disk_type"
        elif key == "enableGracefulDecommission":
            suggest = "enable_graceful_decommission"
        elif key == "gpuDriver":
            suggest = "gpu_driver"
        elif key == "hostGroupName":
            suggest = "host_group_name"
        elif key == "hostGroupType":
            suggest = "host_group_type"
        elif key == "instanceList":
            suggest = "instance_list"
        elif key == "instanceType":
            suggest = "instance_type"
        elif key == "nodeCount":
            suggest = "node_count"
        elif key == "sysDiskCapacity":
            suggest = "sys_disk_capacity"
        elif key == "sysDiskType":
            suggest = "sys_disk_type"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ClusterHostGroup. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ClusterHostGroup.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ClusterHostGroup.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 auto_renew: Optional[bool] = None,
                 charge_type: Optional[str] = None,
                 decommission_timeout: Optional[int] = None,
                 disk_capacity: Optional[str] = None,
                 disk_count: Optional[str] = None,
                 disk_type: Optional[str] = None,
                 enable_graceful_decommission: Optional[bool] = None,
                 gpu_driver: Optional[str] = None,
                 host_group_name: Optional[str] = None,
                 host_group_type: Optional[str] = None,
                 instance_list: Optional[str] = None,
                 instance_type: Optional[str] = None,
                 node_count: Optional[str] = None,
                 period: Optional[int] = None,
                 sys_disk_capacity: Optional[str] = None,
                 sys_disk_type: Optional[str] = None):
        """
        :param bool auto_renew: Auto renew for prepaid, ’true’ or ‘false’ . Default value: false.
        :param str charge_type: Charge Type for this cluster. Supported value: PostPaid or PrePaid. Default value: PostPaid.
        :param int decommission_timeout: Graceful decommission timeout, unit: seconds.
        :param str disk_capacity: Data disk capacity.
        :param str disk_count: Data disk count.
        :param str disk_type: Data disk type. Supported value: cloud,cloud_efficiency,cloud_ssd,local_disk,cloud_essd.
        :param bool enable_graceful_decommission: Enable hadoop cluster of task node graceful decommission, ’true’ or ‘false’ . Default value: false.
        :param str host_group_name: host group name.
        :param str host_group_type: host group type, supported value: MASTER, CORE or TASK, supported 'GATEWAY' available in 1.61.0+.
        :param str instance_list: Instance list for cluster scale down. This value follows the json format, e.g. ["instance_id1","instance_id2"]. escape character for " is \\".
        :param str instance_type: Host Ecs instance type.
        :param str node_count: Host number in this group.
        :param int period: If charge type is PrePaid, this should be specified, unit is month. Supported value: 1、2、3、4、5、6、7、8、9、12、24、36.
        :param str sys_disk_capacity: System disk capacity.
        :param str sys_disk_type: System disk type. Supported value: cloud,cloud_efficiency,cloud_ssd,cloud_essd.
        """
        if auto_renew is not None:
            pulumi.set(__self__, "auto_renew", auto_renew)
        if charge_type is not None:
            pulumi.set(__self__, "charge_type", charge_type)
        if decommission_timeout is not None:
            pulumi.set(__self__, "decommission_timeout", decommission_timeout)
        if disk_capacity is not None:
            pulumi.set(__self__, "disk_capacity", disk_capacity)
        if disk_count is not None:
            pulumi.set(__self__, "disk_count", disk_count)
        if disk_type is not None:
            pulumi.set(__self__, "disk_type", disk_type)
        if enable_graceful_decommission is not None:
            pulumi.set(__self__, "enable_graceful_decommission", enable_graceful_decommission)
        if gpu_driver is not None:
            pulumi.set(__self__, "gpu_driver", gpu_driver)
        if host_group_name is not None:
            pulumi.set(__self__, "host_group_name", host_group_name)
        if host_group_type is not None:
            pulumi.set(__self__, "host_group_type", host_group_type)
        if instance_list is not None:
            pulumi.set(__self__, "instance_list", instance_list)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if node_count is not None:
            pulumi.set(__self__, "node_count", node_count)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if sys_disk_capacity is not None:
            pulumi.set(__self__, "sys_disk_capacity", sys_disk_capacity)
        if sys_disk_type is not None:
            pulumi.set(__self__, "sys_disk_type", sys_disk_type)

    @property
    @pulumi.getter(name="autoRenew")
    def auto_renew(self) -> Optional[bool]:
        """
        Auto renew for prepaid, ’true’ or ‘false’ . Default value: false.
        """
        return pulumi.get(self, "auto_renew")

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> Optional[str]:
        """
        Charge Type for this cluster. Supported value: PostPaid or PrePaid. Default value: PostPaid.
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="decommissionTimeout")
    def decommission_timeout(self) -> Optional[int]:
        """
        Graceful decommission timeout, unit: seconds.
        """
        return pulumi.get(self, "decommission_timeout")

    @property
    @pulumi.getter(name="diskCapacity")
    def disk_capacity(self) -> Optional[str]:
        """
        Data disk capacity.
        """
        return pulumi.get(self, "disk_capacity")

    @property
    @pulumi.getter(name="diskCount")
    def disk_count(self) -> Optional[str]:
        """
        Data disk count.
        """
        return pulumi.get(self, "disk_count")

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> Optional[str]:
        """
        Data disk type. Supported value: cloud,cloud_efficiency,cloud_ssd,local_disk,cloud_essd.
        """
        return pulumi.get(self, "disk_type")

    @property
    @pulumi.getter(name="enableGracefulDecommission")
    def enable_graceful_decommission(self) -> Optional[bool]:
        """
        Enable hadoop cluster of task node graceful decommission, ’true’ or ‘false’ . Default value: false.
        """
        return pulumi.get(self, "enable_graceful_decommission")

    @property
    @pulumi.getter(name="gpuDriver")
    def gpu_driver(self) -> Optional[str]:
        return pulumi.get(self, "gpu_driver")

    @property
    @pulumi.getter(name="hostGroupName")
    def host_group_name(self) -> Optional[str]:
        """
        host group name.
        """
        return pulumi.get(self, "host_group_name")

    @property
    @pulumi.getter(name="hostGroupType")
    def host_group_type(self) -> Optional[str]:
        """
        host group type, supported value: MASTER, CORE or TASK, supported 'GATEWAY' available in 1.61.0+.
        """
        return pulumi.get(self, "host_group_type")

    @property
    @pulumi.getter(name="instanceList")
    def instance_list(self) -> Optional[str]:
        """
        Instance list for cluster scale down. This value follows the json format, e.g. ["instance_id1","instance_id2"]. escape character for " is \\".
        """
        return pulumi.get(self, "instance_list")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[str]:
        """
        Host Ecs instance type.
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> Optional[str]:
        """
        Host number in this group.
        """
        return pulumi.get(self, "node_count")

    @property
    @pulumi.getter
    def period(self) -> Optional[int]:
        """
        If charge type is PrePaid, this should be specified, unit is month. Supported value: 1、2、3、4、5、6、7、8、9、12、24、36.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="sysDiskCapacity")
    def sys_disk_capacity(self) -> Optional[str]:
        """
        System disk capacity.
        """
        return pulumi.get(self, "sys_disk_capacity")

    @property
    @pulumi.getter(name="sysDiskType")
    def sys_disk_type(self) -> Optional[str]:
        """
        System disk type. Supported value: cloud,cloud_efficiency,cloud_ssd,cloud_essd.
        """
        return pulumi.get(self, "sys_disk_type")


@pulumi.output_type
class ClusterMetaStoreConf(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "dbPassword":
            suggest = "db_password"
        elif key == "dbUrl":
            suggest = "db_url"
        elif key == "dbUserName":
            suggest = "db_user_name"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ClusterMetaStoreConf. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ClusterMetaStoreConf.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ClusterMetaStoreConf.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 db_password: str,
                 db_url: str,
                 db_user_name: str):
        """
        :param str db_password: Custom rds database password.
        :param str db_url: Custom rds database connection url.
        :param str db_user_name: Custom rds database user name.
        """
        pulumi.set(__self__, "db_password", db_password)
        pulumi.set(__self__, "db_url", db_url)
        pulumi.set(__self__, "db_user_name", db_user_name)

    @property
    @pulumi.getter(name="dbPassword")
    def db_password(self) -> str:
        """
        Custom rds database password.
        """
        return pulumi.get(self, "db_password")

    @property
    @pulumi.getter(name="dbUrl")
    def db_url(self) -> str:
        """
        Custom rds database connection url.
        """
        return pulumi.get(self, "db_url")

    @property
    @pulumi.getter(name="dbUserName")
    def db_user_name(self) -> str:
        """
        Custom rds database user name.
        """
        return pulumi.get(self, "db_user_name")


@pulumi.output_type
class ClusterModifyClusterServiceConfig(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "configParams":
            suggest = "config_params"
        elif key == "serviceName":
            suggest = "service_name"
        elif key == "configType":
            suggest = "config_type"
        elif key == "customConfigParams":
            suggest = "custom_config_params"
        elif key == "gatewayClusterIdLists":
            suggest = "gateway_cluster_id_lists"
        elif key == "groupId":
            suggest = "group_id"
        elif key == "hostInstanceId":
            suggest = "host_instance_id"
        elif key == "refreshHostConfig":
            suggest = "refresh_host_config"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in ClusterModifyClusterServiceConfig. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        ClusterModifyClusterServiceConfig.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        ClusterModifyClusterServiceConfig.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 config_params: str,
                 service_name: str,
                 comment: Optional[str] = None,
                 config_type: Optional[str] = None,
                 custom_config_params: Optional[str] = None,
                 gateway_cluster_id_lists: Optional[Sequence[str]] = None,
                 group_id: Optional[str] = None,
                 host_instance_id: Optional[str] = None,
                 refresh_host_config: Optional[bool] = None):
        """
        :param str config_params: Cluster service configuration modification params, e.g. ’{"hdfs-site":{"dfs.replication":"3"}}’.
        :param str comment: Cluster service configuration modification comment, e.g. "Modify tez configuration".
        :param str config_type: Cluster service configuration modification type.
        :param str custom_config_params: Cluster service configuration modification custom params, e.g. ’{"tez-site":{"key":{"Value":"value"}}}’.
        :param Sequence[str] gateway_cluster_id_lists: Cluster service configuration modification related gateway cluster id list.
        :param str group_id: Cluster service configuration modification node group id, e.g. ’G-XXX’.
        :param str host_instance_id: Cluster service configuration modification host instance id, e.g. ’i-bp146tnrkq4tcxxxxx’.
        :param bool refresh_host_config: Cluster service configuration modification refresh host config, ’true’ or ’false’.
        """
        pulumi.set(__self__, "config_params", config_params)
        pulumi.set(__self__, "service_name", service_name)
        if comment is not None:
            pulumi.set(__self__, "comment", comment)
        if config_type is not None:
            pulumi.set(__self__, "config_type", config_type)
        if custom_config_params is not None:
            pulumi.set(__self__, "custom_config_params", custom_config_params)
        if gateway_cluster_id_lists is not None:
            pulumi.set(__self__, "gateway_cluster_id_lists", gateway_cluster_id_lists)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if host_instance_id is not None:
            pulumi.set(__self__, "host_instance_id", host_instance_id)
        if refresh_host_config is not None:
            pulumi.set(__self__, "refresh_host_config", refresh_host_config)

    @property
    @pulumi.getter(name="configParams")
    def config_params(self) -> str:
        """
        Cluster service configuration modification params, e.g. ’{"hdfs-site":{"dfs.replication":"3"}}’.
        """
        return pulumi.get(self, "config_params")

    @property
    @pulumi.getter(name="serviceName")
    def service_name(self) -> str:
        return pulumi.get(self, "service_name")

    @property
    @pulumi.getter
    def comment(self) -> Optional[str]:
        """
        Cluster service configuration modification comment, e.g. "Modify tez configuration".
        """
        return pulumi.get(self, "comment")

    @property
    @pulumi.getter(name="configType")
    def config_type(self) -> Optional[str]:
        """
        Cluster service configuration modification type.
        """
        return pulumi.get(self, "config_type")

    @property
    @pulumi.getter(name="customConfigParams")
    def custom_config_params(self) -> Optional[str]:
        """
        Cluster service configuration modification custom params, e.g. ’{"tez-site":{"key":{"Value":"value"}}}’.
        """
        return pulumi.get(self, "custom_config_params")

    @property
    @pulumi.getter(name="gatewayClusterIdLists")
    def gateway_cluster_id_lists(self) -> Optional[Sequence[str]]:
        """
        Cluster service configuration modification related gateway cluster id list.
        """
        return pulumi.get(self, "gateway_cluster_id_lists")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[str]:
        """
        Cluster service configuration modification node group id, e.g. ’G-XXX’.
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="hostInstanceId")
    def host_instance_id(self) -> Optional[str]:
        """
        Cluster service configuration modification host instance id, e.g. ’i-bp146tnrkq4tcxxxxx’.
        """
        return pulumi.get(self, "host_instance_id")

    @property
    @pulumi.getter(name="refreshHostConfig")
    def refresh_host_config(self) -> Optional[bool]:
        """
        Cluster service configuration modification refresh host config, ’true’ or ’false’.
        """
        return pulumi.get(self, "refresh_host_config")


@pulumi.output_type
class GetClustersClusterResult(dict):
    def __init__(__self__, *,
                 access_infos: Sequence['outputs.GetClustersClusterAccessInfoResult'],
                 auto_scaling_allowed: bool,
                 auto_scaling_by_load_allowed: bool,
                 auto_scaling_enable: bool,
                 auto_scaling_spot_with_limit_allowed: bool,
                 bootstrap_action_lists: Sequence['outputs.GetClustersClusterBootstrapActionListResult'],
                 bootstrap_failed: bool,
                 cluster_id: str,
                 cluster_name: str,
                 create_resource: str,
                 create_time: str,
                 create_type: str,
                 deposit_type: str,
                 eas_enable: bool,
                 expired_time: str,
                 extra_info: str,
                 has_uncompleted_order: bool,
                 high_availability_enable: bool,
                 host_group_lists: Sequence['outputs.GetClustersClusterHostGroupListResult'],
                 host_pool_infos: Sequence['outputs.GetClustersClusterHostPoolInfoResult'],
                 id: str,
                 image_id: str,
                 local_meta_db: bool,
                 machine_type: str,
                 meta_store_type: str,
                 net_type: str,
                 payment_type: str,
                 period: int,
                 relate_cluster_infos: Sequence['outputs.GetClustersClusterRelateClusterInfoResult'],
                 resize_disk_enable: bool,
                 running_time: int,
                 security_group_id: str,
                 security_group_name: str,
                 software_infos: Sequence['outputs.GetClustersClusterSoftwareInfoResult'],
                 start_time: str,
                 status: str,
                 stop_time: str,
                 tags: Mapping[str, str],
                 type: str,
                 user_defined_emr_ecs_role: str,
                 user_id: str,
                 vpc_id: str,
                 vswitch_id: str,
                 zone_id: str):
        """
        :param Sequence['GetClustersClusterAccessInfoArgs'] access_infos: Cluster connection information.
        :param bool auto_scaling_allowed: Whether flexible expansion is allowed.
        :param bool auto_scaling_by_load_allowed: Whether to allow expansion by load.
        :param bool auto_scaling_enable: Whether to enable elastic expansion.
        :param bool auto_scaling_spot_with_limit_allowed: Whether to allow the use of elastic scaling bidding instances.
        :param Sequence['GetClustersClusterBootstrapActionListArgs'] bootstrap_action_lists: List of boot actions.
        :param bool bootstrap_failed: The result of the boot operation.
        :param str cluster_id: The first ID of the resource.
        :param str cluster_name: The ClusterName.
        :param str create_resource: Cluster tag, no need to pay attention.
        :param str create_time: The creation time of the resource.
        :param str create_type: How to create a cluster.
        :param str deposit_type: The hosting type of the cluster.
        :param bool eas_enable: High security cluster.
        :param str expired_time: The expiration time of the cluster.
        :param str extra_info: Additional information for Stack.
        :param bool high_availability_enable: High availability cluster.
        :param Sequence['GetClustersClusterHostGroupListArgs'] host_group_lists: List of cluster machine groups.
        :param Sequence['GetClustersClusterHostPoolInfoArgs'] host_pool_infos: Machine pool information.
        :param str image_id: The ID of the image used to create the cluster.
        :param bool local_meta_db: Whether to use Hive local Metabase.
        :param str machine_type: The host type of the cluster. The default is ECS.
        :param str meta_store_type: Metadata type:
        :param str net_type: Cluster network type.
        :param str payment_type: The payment type of the resource.
        :param int period: The package year and month time of the machine group. The Valid Values : `1`, `2`, `3`, `4`, `5`, `6`, `7`, `8`, `9`, `12`, `24`, `36`.
        :param Sequence['GetClustersClusterRelateClusterInfoArgs'] relate_cluster_infos: The information of the primary cluster associated with the Gateway.
        :param bool resize_disk_enable: Whether to allow disk expansion:
        :param int running_time: The time (in seconds) that has been running.
        :param str security_group_id: The ID of the security group.
        :param str security_group_name: The name of the security group.
        :param Sequence['GetClustersClusterSoftwareInfoArgs'] software_infos: Service list.
        :param str start_time: Cluster startup time.
        :param str status: The cluster status.
        :param str stop_time: Cluster stop time.
        :param Mapping[str, str] tags: A mapping of tags to assign to the resource.
        :param str type: Disk type.
        :param str user_defined_emr_ecs_role: The EMR permission name used.
        :param str user_id: The user ID.
        :param str vpc_id: The VPC ID.
        :param str vswitch_id: The vswitch id.
        :param str zone_id: The zone ID.
        """
        pulumi.set(__self__, "access_infos", access_infos)
        pulumi.set(__self__, "auto_scaling_allowed", auto_scaling_allowed)
        pulumi.set(__self__, "auto_scaling_by_load_allowed", auto_scaling_by_load_allowed)
        pulumi.set(__self__, "auto_scaling_enable", auto_scaling_enable)
        pulumi.set(__self__, "auto_scaling_spot_with_limit_allowed", auto_scaling_spot_with_limit_allowed)
        pulumi.set(__self__, "bootstrap_action_lists", bootstrap_action_lists)
        pulumi.set(__self__, "bootstrap_failed", bootstrap_failed)
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "cluster_name", cluster_name)
        pulumi.set(__self__, "create_resource", create_resource)
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "create_type", create_type)
        pulumi.set(__self__, "deposit_type", deposit_type)
        pulumi.set(__self__, "eas_enable", eas_enable)
        pulumi.set(__self__, "expired_time", expired_time)
        pulumi.set(__self__, "extra_info", extra_info)
        pulumi.set(__self__, "has_uncompleted_order", has_uncompleted_order)
        pulumi.set(__self__, "high_availability_enable", high_availability_enable)
        pulumi.set(__self__, "host_group_lists", host_group_lists)
        pulumi.set(__self__, "host_pool_infos", host_pool_infos)
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "image_id", image_id)
        pulumi.set(__self__, "local_meta_db", local_meta_db)
        pulumi.set(__self__, "machine_type", machine_type)
        pulumi.set(__self__, "meta_store_type", meta_store_type)
        pulumi.set(__self__, "net_type", net_type)
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "period", period)
        pulumi.set(__self__, "relate_cluster_infos", relate_cluster_infos)
        pulumi.set(__self__, "resize_disk_enable", resize_disk_enable)
        pulumi.set(__self__, "running_time", running_time)
        pulumi.set(__self__, "security_group_id", security_group_id)
        pulumi.set(__self__, "security_group_name", security_group_name)
        pulumi.set(__self__, "software_infos", software_infos)
        pulumi.set(__self__, "start_time", start_time)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "stop_time", stop_time)
        pulumi.set(__self__, "tags", tags)
        pulumi.set(__self__, "type", type)
        pulumi.set(__self__, "user_defined_emr_ecs_role", user_defined_emr_ecs_role)
        pulumi.set(__self__, "user_id", user_id)
        pulumi.set(__self__, "vpc_id", vpc_id)
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="accessInfos")
    def access_infos(self) -> Sequence['outputs.GetClustersClusterAccessInfoResult']:
        """
        Cluster connection information.
        """
        return pulumi.get(self, "access_infos")

    @property
    @pulumi.getter(name="autoScalingAllowed")
    def auto_scaling_allowed(self) -> bool:
        """
        Whether flexible expansion is allowed.
        """
        return pulumi.get(self, "auto_scaling_allowed")

    @property
    @pulumi.getter(name="autoScalingByLoadAllowed")
    def auto_scaling_by_load_allowed(self) -> bool:
        """
        Whether to allow expansion by load.
        """
        return pulumi.get(self, "auto_scaling_by_load_allowed")

    @property
    @pulumi.getter(name="autoScalingEnable")
    def auto_scaling_enable(self) -> bool:
        """
        Whether to enable elastic expansion.
        """
        return pulumi.get(self, "auto_scaling_enable")

    @property
    @pulumi.getter(name="autoScalingSpotWithLimitAllowed")
    def auto_scaling_spot_with_limit_allowed(self) -> bool:
        """
        Whether to allow the use of elastic scaling bidding instances.
        """
        return pulumi.get(self, "auto_scaling_spot_with_limit_allowed")

    @property
    @pulumi.getter(name="bootstrapActionLists")
    def bootstrap_action_lists(self) -> Sequence['outputs.GetClustersClusterBootstrapActionListResult']:
        """
        List of boot actions.
        """
        return pulumi.get(self, "bootstrap_action_lists")

    @property
    @pulumi.getter(name="bootstrapFailed")
    def bootstrap_failed(self) -> bool:
        """
        The result of the boot operation.
        """
        return pulumi.get(self, "bootstrap_failed")

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> str:
        """
        The first ID of the resource.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> str:
        """
        The ClusterName.
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter(name="createResource")
    def create_resource(self) -> str:
        """
        Cluster tag, no need to pay attention.
        """
        return pulumi.get(self, "create_resource")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        The creation time of the resource.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="createType")
    def create_type(self) -> str:
        """
        How to create a cluster.
        """
        return pulumi.get(self, "create_type")

    @property
    @pulumi.getter(name="depositType")
    def deposit_type(self) -> str:
        """
        The hosting type of the cluster.
        """
        return pulumi.get(self, "deposit_type")

    @property
    @pulumi.getter(name="easEnable")
    def eas_enable(self) -> bool:
        """
        High security cluster.
        """
        return pulumi.get(self, "eas_enable")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> str:
        """
        The expiration time of the cluster.
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter(name="extraInfo")
    def extra_info(self) -> str:
        """
        Additional information for Stack.
        """
        return pulumi.get(self, "extra_info")

    @property
    @pulumi.getter(name="hasUncompletedOrder")
    def has_uncompleted_order(self) -> bool:
        return pulumi.get(self, "has_uncompleted_order")

    @property
    @pulumi.getter(name="highAvailabilityEnable")
    def high_availability_enable(self) -> bool:
        """
        High availability cluster.
        """
        return pulumi.get(self, "high_availability_enable")

    @property
    @pulumi.getter(name="hostGroupLists")
    def host_group_lists(self) -> Sequence['outputs.GetClustersClusterHostGroupListResult']:
        """
        List of cluster machine groups.
        """
        return pulumi.get(self, "host_group_lists")

    @property
    @pulumi.getter(name="hostPoolInfos")
    def host_pool_infos(self) -> Sequence['outputs.GetClustersClusterHostPoolInfoResult']:
        """
        Machine pool information.
        """
        return pulumi.get(self, "host_pool_infos")

    @property
    @pulumi.getter
    def id(self) -> str:
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> str:
        """
        The ID of the image used to create the cluster.
        """
        return pulumi.get(self, "image_id")

    @property
    @pulumi.getter(name="localMetaDb")
    def local_meta_db(self) -> bool:
        """
        Whether to use Hive local Metabase.
        """
        return pulumi.get(self, "local_meta_db")

    @property
    @pulumi.getter(name="machineType")
    def machine_type(self) -> str:
        """
        The host type of the cluster. The default is ECS.
        """
        return pulumi.get(self, "machine_type")

    @property
    @pulumi.getter(name="metaStoreType")
    def meta_store_type(self) -> str:
        """
        Metadata type:
        """
        return pulumi.get(self, "meta_store_type")

    @property
    @pulumi.getter(name="netType")
    def net_type(self) -> str:
        """
        Cluster network type.
        """
        return pulumi.get(self, "net_type")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> str:
        """
        The payment type of the resource.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def period(self) -> int:
        """
        The package year and month time of the machine group. The Valid Values : `1`, `2`, `3`, `4`, `5`, `6`, `7`, `8`, `9`, `12`, `24`, `36`.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="relateClusterInfos")
    def relate_cluster_infos(self) -> Sequence['outputs.GetClustersClusterRelateClusterInfoResult']:
        """
        The information of the primary cluster associated with the Gateway.
        """
        return pulumi.get(self, "relate_cluster_infos")

    @property
    @pulumi.getter(name="resizeDiskEnable")
    def resize_disk_enable(self) -> bool:
        """
        Whether to allow disk expansion:
        """
        return pulumi.get(self, "resize_disk_enable")

    @property
    @pulumi.getter(name="runningTime")
    def running_time(self) -> int:
        """
        The time (in seconds) that has been running.
        """
        return pulumi.get(self, "running_time")

    @property
    @pulumi.getter(name="securityGroupId")
    def security_group_id(self) -> str:
        """
        The ID of the security group.
        """
        return pulumi.get(self, "security_group_id")

    @property
    @pulumi.getter(name="securityGroupName")
    def security_group_name(self) -> str:
        """
        The name of the security group.
        """
        return pulumi.get(self, "security_group_name")

    @property
    @pulumi.getter(name="softwareInfos")
    def software_infos(self) -> Sequence['outputs.GetClustersClusterSoftwareInfoResult']:
        """
        Service list.
        """
        return pulumi.get(self, "software_infos")

    @property
    @pulumi.getter(name="startTime")
    def start_time(self) -> str:
        """
        Cluster startup time.
        """
        return pulumi.get(self, "start_time")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The cluster status.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="stopTime")
    def stop_time(self) -> str:
        """
        Cluster stop time.
        """
        return pulumi.get(self, "stop_time")

    @property
    @pulumi.getter
    def tags(self) -> Mapping[str, str]:
        """
        A mapping of tags to assign to the resource.
        """
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Disk type.
        """
        return pulumi.get(self, "type")

    @property
    @pulumi.getter(name="userDefinedEmrEcsRole")
    def user_defined_emr_ecs_role(self) -> str:
        """
        The EMR permission name used.
        """
        return pulumi.get(self, "user_defined_emr_ecs_role")

    @property
    @pulumi.getter(name="userId")
    def user_id(self) -> str:
        """
        The user ID.
        """
        return pulumi.get(self, "user_id")

    @property
    @pulumi.getter(name="vpcId")
    def vpc_id(self) -> str:
        """
        The VPC ID.
        """
        return pulumi.get(self, "vpc_id")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> str:
        """
        The vswitch id.
        """
        return pulumi.get(self, "vswitch_id")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        """
        The zone ID.
        """
        return pulumi.get(self, "zone_id")


@pulumi.output_type
class GetClustersClusterAccessInfoResult(dict):
    def __init__(__self__, *,
                 zk_links: Sequence['outputs.GetClustersClusterAccessInfoZkLinkResult']):
        """
        :param Sequence['GetClustersClusterAccessInfoZkLinkArgs'] zk_links: Link address information list of ZooKeeper.
        """
        pulumi.set(__self__, "zk_links", zk_links)

    @property
    @pulumi.getter(name="zkLinks")
    def zk_links(self) -> Sequence['outputs.GetClustersClusterAccessInfoZkLinkResult']:
        """
        Link address information list of ZooKeeper.
        """
        return pulumi.get(self, "zk_links")


@pulumi.output_type
class GetClustersClusterAccessInfoZkLinkResult(dict):
    def __init__(__self__, *,
                 link: str,
                 port: str):
        """
        :param str link: The access link address of ZooKeeper.
        :param str port: The port of ZooKeeper.
        """
        pulumi.set(__self__, "link", link)
        pulumi.set(__self__, "port", port)

    @property
    @pulumi.getter
    def link(self) -> str:
        """
        The access link address of ZooKeeper.
        """
        return pulumi.get(self, "link")

    @property
    @pulumi.getter
    def port(self) -> str:
        """
        The port of ZooKeeper.
        """
        return pulumi.get(self, "port")


@pulumi.output_type
class GetClustersClusterBootstrapActionListResult(dict):
    def __init__(__self__, *,
                 arg: str,
                 name: str,
                 path: str):
        """
        :param str arg: Parameters of the boot operation.
        :param str name: The name of the boot operation.
        :param str path: Boot operation script path.
        """
        pulumi.set(__self__, "arg", arg)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "path", path)

    @property
    @pulumi.getter
    def arg(self) -> str:
        """
        Parameters of the boot operation.
        """
        return pulumi.get(self, "arg")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The name of the boot operation.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter
    def path(self) -> str:
        """
        Boot operation script path.
        """
        return pulumi.get(self, "path")


@pulumi.output_type
class GetClustersClusterHostGroupListResult(dict):
    def __init__(__self__, *,
                 band_width: str,
                 charge_type: str,
                 cpu_core: int,
                 disk_capacity: int,
                 disk_count: int,
                 disk_type: str,
                 host_group_change_type: str,
                 host_group_id: str,
                 host_group_name: str,
                 host_group_type: str,
                 instance_type: str,
                 memory_capacity: int,
                 node_count: int,
                 nodes: Sequence['outputs.GetClustersClusterHostGroupListNodeResult'],
                 period: str):
        """
        :param str band_width: Bandwidth.
        :param str charge_type: Payment Type.
        :param int cpu_core: The number of CPU cores.
        :param int disk_capacity: Data disk capacity.
        :param int disk_count: The number of data disks.
        :param str disk_type: System disk type:
        :param str host_group_change_type: The current operation type of the machine Group:
        :param str host_group_id: The ID of the machine group.
        :param str host_group_name: The name of the machine group.
        :param str host_group_type: Role of host in cluster:
        :param str instance_type: Machine Group instance.
        :param int memory_capacity: Memory size.
        :param int node_count: The number of machine group nodes.
        :param Sequence['GetClustersClusterHostGroupListNodeArgs'] nodes: Machine node.
        :param str period: Package year and month time (days).
        """
        pulumi.set(__self__, "band_width", band_width)
        pulumi.set(__self__, "charge_type", charge_type)
        pulumi.set(__self__, "cpu_core", cpu_core)
        pulumi.set(__self__, "disk_capacity", disk_capacity)
        pulumi.set(__self__, "disk_count", disk_count)
        pulumi.set(__self__, "disk_type", disk_type)
        pulumi.set(__self__, "host_group_change_type", host_group_change_type)
        pulumi.set(__self__, "host_group_id", host_group_id)
        pulumi.set(__self__, "host_group_name", host_group_name)
        pulumi.set(__self__, "host_group_type", host_group_type)
        pulumi.set(__self__, "instance_type", instance_type)
        pulumi.set(__self__, "memory_capacity", memory_capacity)
        pulumi.set(__self__, "node_count", node_count)
        pulumi.set(__self__, "nodes", nodes)
        pulumi.set(__self__, "period", period)

    @property
    @pulumi.getter(name="bandWidth")
    def band_width(self) -> str:
        """
        Bandwidth.
        """
        return pulumi.get(self, "band_width")

    @property
    @pulumi.getter(name="chargeType")
    def charge_type(self) -> str:
        """
        Payment Type.
        """
        return pulumi.get(self, "charge_type")

    @property
    @pulumi.getter(name="cpuCore")
    def cpu_core(self) -> int:
        """
        The number of CPU cores.
        """
        return pulumi.get(self, "cpu_core")

    @property
    @pulumi.getter(name="diskCapacity")
    def disk_capacity(self) -> int:
        """
        Data disk capacity.
        """
        return pulumi.get(self, "disk_capacity")

    @property
    @pulumi.getter(name="diskCount")
    def disk_count(self) -> int:
        """
        The number of data disks.
        """
        return pulumi.get(self, "disk_count")

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> str:
        """
        System disk type:
        """
        return pulumi.get(self, "disk_type")

    @property
    @pulumi.getter(name="hostGroupChangeType")
    def host_group_change_type(self) -> str:
        """
        The current operation type of the machine Group:
        """
        return pulumi.get(self, "host_group_change_type")

    @property
    @pulumi.getter(name="hostGroupId")
    def host_group_id(self) -> str:
        """
        The ID of the machine group.
        """
        return pulumi.get(self, "host_group_id")

    @property
    @pulumi.getter(name="hostGroupName")
    def host_group_name(self) -> str:
        """
        The name of the machine group.
        """
        return pulumi.get(self, "host_group_name")

    @property
    @pulumi.getter(name="hostGroupType")
    def host_group_type(self) -> str:
        """
        Role of host in cluster:
        """
        return pulumi.get(self, "host_group_type")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> str:
        """
        Machine Group instance.
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter(name="memoryCapacity")
    def memory_capacity(self) -> int:
        """
        Memory size.
        """
        return pulumi.get(self, "memory_capacity")

    @property
    @pulumi.getter(name="nodeCount")
    def node_count(self) -> int:
        """
        The number of machine group nodes.
        """
        return pulumi.get(self, "node_count")

    @property
    @pulumi.getter
    def nodes(self) -> Sequence['outputs.GetClustersClusterHostGroupListNodeResult']:
        """
        Machine node.
        """
        return pulumi.get(self, "nodes")

    @property
    @pulumi.getter
    def period(self) -> str:
        """
        Package year and month time (days).
        """
        return pulumi.get(self, "period")


@pulumi.output_type
class GetClustersClusterHostGroupListNodeResult(dict):
    def __init__(__self__, *,
                 create_time: str,
                 disk_infos: Sequence['outputs.GetClustersClusterHostGroupListNodeDiskInfoResult'],
                 emr_expired_time: str,
                 expired_time: str,
                 inner_ip: str,
                 instance_id: str,
                 pub_ip: str,
                 status: str,
                 support_ipv6: bool,
                 zone_id: str):
        """
        :param str create_time: Creation time.
        :param Sequence['GetClustersClusterHostGroupListNodeDiskInfoArgs'] disk_infos: Disk information.
        :param str emr_expired_time: The timeout of the EMR.
        :param str expired_time: Timeout time.
        :param str inner_ip: The Intranet IP of the EMR.
        :param str instance_id: The ID of the ECS instance.
        :param str pub_ip: Public IP address.
        :param str status: Status.
        :param bool support_ipv6: Whether IPV6 is supported.
        :param str zone_id: The zone ID.
        """
        pulumi.set(__self__, "create_time", create_time)
        pulumi.set(__self__, "disk_infos", disk_infos)
        pulumi.set(__self__, "emr_expired_time", emr_expired_time)
        pulumi.set(__self__, "expired_time", expired_time)
        pulumi.set(__self__, "inner_ip", inner_ip)
        pulumi.set(__self__, "instance_id", instance_id)
        pulumi.set(__self__, "pub_ip", pub_ip)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "support_ipv6", support_ipv6)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> str:
        """
        Creation time.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="diskInfos")
    def disk_infos(self) -> Sequence['outputs.GetClustersClusterHostGroupListNodeDiskInfoResult']:
        """
        Disk information.
        """
        return pulumi.get(self, "disk_infos")

    @property
    @pulumi.getter(name="emrExpiredTime")
    def emr_expired_time(self) -> str:
        """
        The timeout of the EMR.
        """
        return pulumi.get(self, "emr_expired_time")

    @property
    @pulumi.getter(name="expiredTime")
    def expired_time(self) -> str:
        """
        Timeout time.
        """
        return pulumi.get(self, "expired_time")

    @property
    @pulumi.getter(name="innerIp")
    def inner_ip(self) -> str:
        """
        The Intranet IP of the EMR.
        """
        return pulumi.get(self, "inner_ip")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> str:
        """
        The ID of the ECS instance.
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="pubIp")
    def pub_ip(self) -> str:
        """
        Public IP address.
        """
        return pulumi.get(self, "pub_ip")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        Status.
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="supportIpv6")
    def support_ipv6(self) -> bool:
        """
        Whether IPV6 is supported.
        """
        return pulumi.get(self, "support_ipv6")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        """
        The zone ID.
        """
        return pulumi.get(self, "zone_id")


@pulumi.output_type
class GetClustersClusterHostGroupListNodeDiskInfoResult(dict):
    def __init__(__self__, *,
                 device: str,
                 disk_id: str,
                 disk_name: str,
                 size: int,
                 type: str):
        """
        :param str device: The disk name.
        :param str disk_id: The ID of the disk.
        :param str disk_name: The disk name.
        :param int size: Disk capacity.
        :param str type: Disk type.
        """
        pulumi.set(__self__, "device", device)
        pulumi.set(__self__, "disk_id", disk_id)
        pulumi.set(__self__, "disk_name", disk_name)
        pulumi.set(__self__, "size", size)
        pulumi.set(__self__, "type", type)

    @property
    @pulumi.getter
    def device(self) -> str:
        """
        The disk name.
        """
        return pulumi.get(self, "device")

    @property
    @pulumi.getter(name="diskId")
    def disk_id(self) -> str:
        """
        The ID of the disk.
        """
        return pulumi.get(self, "disk_id")

    @property
    @pulumi.getter(name="diskName")
    def disk_name(self) -> str:
        """
        The disk name.
        """
        return pulumi.get(self, "disk_name")

    @property
    @pulumi.getter
    def size(self) -> int:
        """
        Disk capacity.
        """
        return pulumi.get(self, "size")

    @property
    @pulumi.getter
    def type(self) -> str:
        """
        Disk type.
        """
        return pulumi.get(self, "type")


@pulumi.output_type
class GetClustersClusterHostPoolInfoResult(dict):
    def __init__(__self__, *,
                 hp_biz_id: str,
                 hp_name: str):
        """
        :param str hp_biz_id: Machine pool ID.
        :param str hp_name: The name of the machine pool.
        """
        pulumi.set(__self__, "hp_biz_id", hp_biz_id)
        pulumi.set(__self__, "hp_name", hp_name)

    @property
    @pulumi.getter(name="hpBizId")
    def hp_biz_id(self) -> str:
        """
        Machine pool ID.
        """
        return pulumi.get(self, "hp_biz_id")

    @property
    @pulumi.getter(name="hpName")
    def hp_name(self) -> str:
        """
        The name of the machine pool.
        """
        return pulumi.get(self, "hp_name")


@pulumi.output_type
class GetClustersClusterRelateClusterInfoResult(dict):
    def __init__(__self__, *,
                 cluster_id: str,
                 cluster_name: str,
                 cluster_type: str,
                 status: str):
        """
        :param str cluster_id: The ID of the associated cluster.
        :param str cluster_name: The name of the associated cluster.
        :param str cluster_type: The cluster type of the associated cluster.
        :param str status: The status  of the associated cluster.
        """
        pulumi.set(__self__, "cluster_id", cluster_id)
        pulumi.set(__self__, "cluster_name", cluster_name)
        pulumi.set(__self__, "cluster_type", cluster_type)
        pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="clusterId")
    def cluster_id(self) -> str:
        """
        The ID of the associated cluster.
        """
        return pulumi.get(self, "cluster_id")

    @property
    @pulumi.getter(name="clusterName")
    def cluster_name(self) -> str:
        """
        The name of the associated cluster.
        """
        return pulumi.get(self, "cluster_name")

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> str:
        """
        The cluster type of the associated cluster.
        """
        return pulumi.get(self, "cluster_type")

    @property
    @pulumi.getter
    def status(self) -> str:
        """
        The status  of the associated cluster.
        """
        return pulumi.get(self, "status")


@pulumi.output_type
class GetClustersClusterSoftwareInfoResult(dict):
    def __init__(__self__, *,
                 cluster_type: str,
                 emr_ver: str,
                 softwares: Sequence['outputs.GetClustersClusterSoftwareInfoSoftwareResult']):
        """
        :param str cluster_type: Cluster type:
        :param str emr_ver: E-MapReduce version number.
        :param Sequence['GetClustersClusterSoftwareInfoSoftwareArgs'] softwares: Service list.
        """
        pulumi.set(__self__, "cluster_type", cluster_type)
        pulumi.set(__self__, "emr_ver", emr_ver)
        pulumi.set(__self__, "softwares", softwares)

    @property
    @pulumi.getter(name="clusterType")
    def cluster_type(self) -> str:
        """
        Cluster type:
        """
        return pulumi.get(self, "cluster_type")

    @property
    @pulumi.getter(name="emrVer")
    def emr_ver(self) -> str:
        """
        E-MapReduce version number.
        """
        return pulumi.get(self, "emr_ver")

    @property
    @pulumi.getter
    def softwares(self) -> Sequence['outputs.GetClustersClusterSoftwareInfoSoftwareResult']:
        """
        Service list.
        """
        return pulumi.get(self, "softwares")


@pulumi.output_type
class GetClustersClusterSoftwareInfoSoftwareResult(dict):
    def __init__(__self__, *,
                 display_name: str,
                 name: str,
                 only_display: bool,
                 start_tpe: int,
                 version: str):
        """
        :param str display_name: The name of the service.
        :param str name: The internal name of the service.
        :param bool only_display: Whether it shows.
        :param int start_tpe: Startup type.
        :param str version: Service version.
        """
        pulumi.set(__self__, "display_name", display_name)
        pulumi.set(__self__, "name", name)
        pulumi.set(__self__, "only_display", only_display)
        pulumi.set(__self__, "start_tpe", start_tpe)
        pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="displayName")
    def display_name(self) -> str:
        """
        The name of the service.
        """
        return pulumi.get(self, "display_name")

    @property
    @pulumi.getter
    def name(self) -> str:
        """
        The internal name of the service.
        """
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="onlyDisplay")
    def only_display(self) -> bool:
        """
        Whether it shows.
        """
        return pulumi.get(self, "only_display")

    @property
    @pulumi.getter(name="startTpe")
    def start_tpe(self) -> int:
        """
        Startup type.
        """
        return pulumi.get(self, "start_tpe")

    @property
    @pulumi.getter
    def version(self) -> str:
        """
        Service version.
        """
        return pulumi.get(self, "version")


@pulumi.output_type
class GetDiskTypesTypeResult(dict):
    def __init__(__self__, *,
                 max: int,
                 min: int,
                 value: str):
        """
        :param int max: The maximum value of the data disk to supported the specific instance type
        :param int min: The mininum value of the data disk to supported the specific instance type
        :param str value: The value of the data disk or system disk
        """
        pulumi.set(__self__, "max", max)
        pulumi.set(__self__, "min", min)
        pulumi.set(__self__, "value", value)

    @property
    @pulumi.getter
    def max(self) -> int:
        """
        The maximum value of the data disk to supported the specific instance type
        """
        return pulumi.get(self, "max")

    @property
    @pulumi.getter
    def min(self) -> int:
        """
        The mininum value of the data disk to supported the specific instance type
        """
        return pulumi.get(self, "min")

    @property
    @pulumi.getter
    def value(self) -> str:
        """
        The value of the data disk or system disk
        """
        return pulumi.get(self, "value")


@pulumi.output_type
class GetInstanceTypesTypeResult(dict):
    def __init__(__self__, *,
                 id: str,
                 local_storage_capacity: int,
                 zone_id: str):
        """
        :param str id: The ID of the instance type.
        :param int local_storage_capacity: Local capacity of the applied ecs instance for emr cluster. Unit: GB.
        :param str zone_id: The supported resources of specific zoneId.
        """
        pulumi.set(__self__, "id", id)
        pulumi.set(__self__, "local_storage_capacity", local_storage_capacity)
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The ID of the instance type.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter(name="localStorageCapacity")
    def local_storage_capacity(self) -> int:
        """
        Local capacity of the applied ecs instance for emr cluster. Unit: GB.
        """
        return pulumi.get(self, "local_storage_capacity")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> str:
        """
        The supported resources of specific zoneId.
        """
        return pulumi.get(self, "zone_id")


@pulumi.output_type
class GetMainVersionsMainVersionResult(dict):
    def __init__(__self__, *,
                 cluster_types: Sequence[str],
                 emr_version: str,
                 image_id: str):
        """
        :param Sequence[str] cluster_types: A list of cluster types the emr cluster supported. Possible values: `HADOOP`, `ZOOKEEPER`, `KAFKA`, `DRUID`.
        :param str emr_version: The version of the emr cluster instance. Possible values: `EMR-4.0.0`, `EMR-3.23.0`, `EMR-3.22.0`.
        :param str image_id: The image id of the emr cluster instance.
        """
        pulumi.set(__self__, "cluster_types", cluster_types)
        pulumi.set(__self__, "emr_version", emr_version)
        pulumi.set(__self__, "image_id", image_id)

    @property
    @pulumi.getter(name="clusterTypes")
    def cluster_types(self) -> Sequence[str]:
        """
        A list of cluster types the emr cluster supported. Possible values: `HADOOP`, `ZOOKEEPER`, `KAFKA`, `DRUID`.
        """
        return pulumi.get(self, "cluster_types")

    @property
    @pulumi.getter(name="emrVersion")
    def emr_version(self) -> str:
        """
        The version of the emr cluster instance. Possible values: `EMR-4.0.0`, `EMR-3.23.0`, `EMR-3.22.0`.
        """
        return pulumi.get(self, "emr_version")

    @property
    @pulumi.getter(name="imageId")
    def image_id(self) -> str:
        """
        The image id of the emr cluster instance.
        """
        return pulumi.get(self, "image_id")





# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EipInstanceAttachmentArgs', 'EipInstanceAttachment']

@pulumi.input_type
class EipInstanceAttachmentArgs:
    def __init__(__self__, *,
                 allocation_id: pulumi.Input[str],
                 instance_id: pulumi.Input[str],
                 instance_type: Optional[pulumi.Input[str]] = None,
                 standby: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a EipInstanceAttachment resource.
        :param pulumi.Input[str] allocation_id: The first ID of the resource
        :param pulumi.Input[str] instance_id: Instance ID
        :param pulumi.Input[str] instance_type: The type of the EIP instance. Value:
               - `Nat`:NAT gateway.
               - `SlbInstance`: Server Load Balancer (ELB).
               - `NetworkInterface`: Secondary ENI.
               - `EnsInstance` (default): The ENS instance.
        :param pulumi.Input[bool] standby: Indicates whether the EIP is a backup EIP. Value:
               - true: Spare.
               - false: not standby.
        """
        pulumi.set(__self__, "allocation_id", allocation_id)
        pulumi.set(__self__, "instance_id", instance_id)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if standby is not None:
            pulumi.set(__self__, "standby", standby)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> pulumi.Input[str]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "allocation_id")

    @allocation_id.setter
    def allocation_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "allocation_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Input[str]:
        """
        Instance ID
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the EIP instance. Value:
        - `Nat`:NAT gateway.
        - `SlbInstance`: Server Load Balancer (ELB).
        - `NetworkInterface`: Secondary ENI.
        - `EnsInstance` (default): The ENS instance.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter
    def standby(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether the EIP is a backup EIP. Value:
        - true: Spare.
        - false: not standby.
        """
        return pulumi.get(self, "standby")

    @standby.setter
    def standby(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "standby", value)


@pulumi.input_type
class _EipInstanceAttachmentState:
    def __init__(__self__, *,
                 allocation_id: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 standby: Optional[pulumi.Input[bool]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering EipInstanceAttachment resources.
        :param pulumi.Input[str] allocation_id: The first ID of the resource
        :param pulumi.Input[str] instance_id: Instance ID
        :param pulumi.Input[str] instance_type: The type of the EIP instance. Value:
               - `Nat`:NAT gateway.
               - `SlbInstance`: Server Load Balancer (ELB).
               - `NetworkInterface`: Secondary ENI.
               - `EnsInstance` (default): The ENS instance.
        :param pulumi.Input[bool] standby: Indicates whether the EIP is a backup EIP. Value:
               - true: Spare.
               - false: not standby.
        :param pulumi.Input[str] status: The status of the EIP.
        """
        if allocation_id is not None:
            pulumi.set(__self__, "allocation_id", allocation_id)
        if instance_id is not None:
            pulumi.set(__self__, "instance_id", instance_id)
        if instance_type is not None:
            pulumi.set(__self__, "instance_type", instance_type)
        if standby is not None:
            pulumi.set(__self__, "standby", standby)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> Optional[pulumi.Input[str]]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "allocation_id")

    @allocation_id.setter
    def allocation_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "allocation_id", value)

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> Optional[pulumi.Input[str]]:
        """
        Instance ID
        """
        return pulumi.get(self, "instance_id")

    @instance_id.setter
    def instance_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_id", value)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> Optional[pulumi.Input[str]]:
        """
        The type of the EIP instance. Value:
        - `Nat`:NAT gateway.
        - `SlbInstance`: Server Load Balancer (ELB).
        - `NetworkInterface`: Secondary ENI.
        - `EnsInstance` (default): The ENS instance.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter
    def standby(self) -> Optional[pulumi.Input[bool]]:
        """
        Indicates whether the EIP is a backup EIP. Value:
        - true: Spare.
        - false: not standby.
        """
        return pulumi.get(self, "standby")

    @standby.setter
    def standby(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "standby", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the EIP.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class EipInstanceAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allocation_id: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 standby: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Provides a Ens Eip Instance Attachment resource.

        Bind an EIP to an instance.

        For information about Ens Eip Instance Attachment and how to use it, see [What is Eip Instance Attachment](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.227.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        ens_region_id = config.get("ensRegionId")
        if ens_region_id is None:
            ens_region_id = "cn-chenzhou-telecom_unicom_cmcc"
        default_x_kjq1_w = alicloud.ens.Instance("defaultXKjq1W",
            system_disk={
                "size": 20,
                "category": "cloud_efficiency",
            },
            scheduling_strategy="Concentrate",
            schedule_area_level="Region",
            image_id="centos_6_08_64_20G_alibase_20171208",
            payment_type="Subscription",
            instance_type="ens.sn1.stiny",
            password="12345678abcABC",
            status="Running",
            amount=1,
            internet_charge_type="95BandwidthByMonth",
            instance_name=name,
            auto_use_coupon="true",
            instance_charge_strategy="PriceHighPriority",
            ens_region_id=ens_region_id,
            period_unit="Month")
        defaults_gs_n4e = alicloud.ens.Eip("defaultsGsN4e",
            bandwidth=5,
            eip_name=name,
            ens_region_id=ens_region_id,
            internet_charge_type="95BandwidthByMonth",
            payment_type="PayAsYouGo")
        default = alicloud.ens.EipInstanceAttachment("default",
            instance_id=default_x_kjq1_w.id,
            allocation_id=defaults_gs_n4e.id,
            instance_type="EnsInstance",
            standby=False)
        ```

        ## Import

        Ens Eip Instance Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ens/eipInstanceAttachment:EipInstanceAttachment example <allocation_id>:<instance_id>:<instance_type>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] allocation_id: The first ID of the resource
        :param pulumi.Input[str] instance_id: Instance ID
        :param pulumi.Input[str] instance_type: The type of the EIP instance. Value:
               - `Nat`:NAT gateway.
               - `SlbInstance`: Server Load Balancer (ELB).
               - `NetworkInterface`: Secondary ENI.
               - `EnsInstance` (default): The ENS instance.
        :param pulumi.Input[bool] standby: Indicates whether the EIP is a backup EIP. Value:
               - true: Spare.
               - false: not standby.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EipInstanceAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Ens Eip Instance Attachment resource.

        Bind an EIP to an instance.

        For information about Ens Eip Instance Attachment and how to use it, see [What is Eip Instance Attachment](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.227.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        ens_region_id = config.get("ensRegionId")
        if ens_region_id is None:
            ens_region_id = "cn-chenzhou-telecom_unicom_cmcc"
        default_x_kjq1_w = alicloud.ens.Instance("defaultXKjq1W",
            system_disk={
                "size": 20,
                "category": "cloud_efficiency",
            },
            scheduling_strategy="Concentrate",
            schedule_area_level="Region",
            image_id="centos_6_08_64_20G_alibase_20171208",
            payment_type="Subscription",
            instance_type="ens.sn1.stiny",
            password="12345678abcABC",
            status="Running",
            amount=1,
            internet_charge_type="95BandwidthByMonth",
            instance_name=name,
            auto_use_coupon="true",
            instance_charge_strategy="PriceHighPriority",
            ens_region_id=ens_region_id,
            period_unit="Month")
        defaults_gs_n4e = alicloud.ens.Eip("defaultsGsN4e",
            bandwidth=5,
            eip_name=name,
            ens_region_id=ens_region_id,
            internet_charge_type="95BandwidthByMonth",
            payment_type="PayAsYouGo")
        default = alicloud.ens.EipInstanceAttachment("default",
            instance_id=default_x_kjq1_w.id,
            allocation_id=defaults_gs_n4e.id,
            instance_type="EnsInstance",
            standby=False)
        ```

        ## Import

        Ens Eip Instance Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ens/eipInstanceAttachment:EipInstanceAttachment example <allocation_id>:<instance_id>:<instance_type>
        ```

        :param str resource_name: The name of the resource.
        :param EipInstanceAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EipInstanceAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 allocation_id: Optional[pulumi.Input[str]] = None,
                 instance_id: Optional[pulumi.Input[str]] = None,
                 instance_type: Optional[pulumi.Input[str]] = None,
                 standby: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EipInstanceAttachmentArgs.__new__(EipInstanceAttachmentArgs)

            if allocation_id is None and not opts.urn:
                raise TypeError("Missing required property 'allocation_id'")
            __props__.__dict__["allocation_id"] = allocation_id
            if instance_id is None and not opts.urn:
                raise TypeError("Missing required property 'instance_id'")
            __props__.__dict__["instance_id"] = instance_id
            __props__.__dict__["instance_type"] = instance_type
            __props__.__dict__["standby"] = standby
            __props__.__dict__["status"] = None
        super(EipInstanceAttachment, __self__).__init__(
            'alicloud:ens/eipInstanceAttachment:EipInstanceAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            allocation_id: Optional[pulumi.Input[str]] = None,
            instance_id: Optional[pulumi.Input[str]] = None,
            instance_type: Optional[pulumi.Input[str]] = None,
            standby: Optional[pulumi.Input[bool]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'EipInstanceAttachment':
        """
        Get an existing EipInstanceAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] allocation_id: The first ID of the resource
        :param pulumi.Input[str] instance_id: Instance ID
        :param pulumi.Input[str] instance_type: The type of the EIP instance. Value:
               - `Nat`:NAT gateway.
               - `SlbInstance`: Server Load Balancer (ELB).
               - `NetworkInterface`: Secondary ENI.
               - `EnsInstance` (default): The ENS instance.
        :param pulumi.Input[bool] standby: Indicates whether the EIP is a backup EIP. Value:
               - true: Spare.
               - false: not standby.
        :param pulumi.Input[str] status: The status of the EIP.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EipInstanceAttachmentState.__new__(_EipInstanceAttachmentState)

        __props__.__dict__["allocation_id"] = allocation_id
        __props__.__dict__["instance_id"] = instance_id
        __props__.__dict__["instance_type"] = instance_type
        __props__.__dict__["standby"] = standby
        __props__.__dict__["status"] = status
        return EipInstanceAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="allocationId")
    def allocation_id(self) -> pulumi.Output[str]:
        """
        The first ID of the resource
        """
        return pulumi.get(self, "allocation_id")

    @property
    @pulumi.getter(name="instanceId")
    def instance_id(self) -> pulumi.Output[str]:
        """
        Instance ID
        """
        return pulumi.get(self, "instance_id")

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Output[str]:
        """
        The type of the EIP instance. Value:
        - `Nat`:NAT gateway.
        - `SlbInstance`: Server Load Balancer (ELB).
        - `NetworkInterface`: Secondary ENI.
        - `EnsInstance` (default): The ENS instance.
        """
        return pulumi.get(self, "instance_type")

    @property
    @pulumi.getter
    def standby(self) -> pulumi.Output[Optional[bool]]:
        """
        Indicates whether the EIP is a backup EIP. Value:
        - true: Spare.
        - false: not standby.
        """
        return pulumi.get(self, "standby")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the EIP.
        """
        return pulumi.get(self, "status")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetContainerGroupsResult',
    'AwaitableGetContainerGroupsResult',
    'get_container_groups',
    'get_container_groups_output',
]

@pulumi.output_type
class GetContainerGroupsResult:
    """
    A collection of values returned by getContainerGroups.
    """
    def __init__(__self__, container_group_name=None, enable_details=None, groups=None, id=None, ids=None, limit=None, name_regex=None, names=None, output_file=None, resource_group_id=None, status=None, tags=None, vswitch_id=None, with_event=None, zone_id=None):
        if container_group_name and not isinstance(container_group_name, str):
            raise TypeError("Expected argument 'container_group_name' to be a str")
        pulumi.set(__self__, "container_group_name", container_group_name)
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if groups and not isinstance(groups, list):
            raise TypeError("Expected argument 'groups' to be a list")
        pulumi.set(__self__, "groups", groups)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if limit and not isinstance(limit, int):
            raise TypeError("Expected argument 'limit' to be a int")
        pulumi.set(__self__, "limit", limit)
        if name_regex and not isinstance(name_regex, str):
            raise TypeError("Expected argument 'name_regex' to be a str")
        pulumi.set(__self__, "name_regex", name_regex)
        if names and not isinstance(names, list):
            raise TypeError("Expected argument 'names' to be a list")
        pulumi.set(__self__, "names", names)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if resource_group_id and not isinstance(resource_group_id, str):
            raise TypeError("Expected argument 'resource_group_id' to be a str")
        pulumi.set(__self__, "resource_group_id", resource_group_id)
        if status and not isinstance(status, str):
            raise TypeError("Expected argument 'status' to be a str")
        pulumi.set(__self__, "status", status)
        if tags and not isinstance(tags, dict):
            raise TypeError("Expected argument 'tags' to be a dict")
        pulumi.set(__self__, "tags", tags)
        if vswitch_id and not isinstance(vswitch_id, str):
            raise TypeError("Expected argument 'vswitch_id' to be a str")
        pulumi.set(__self__, "vswitch_id", vswitch_id)
        if with_event and not isinstance(with_event, bool):
            raise TypeError("Expected argument 'with_event' to be a bool")
        pulumi.set(__self__, "with_event", with_event)
        if zone_id and not isinstance(zone_id, str):
            raise TypeError("Expected argument 'zone_id' to be a str")
        pulumi.set(__self__, "zone_id", zone_id)

    @property
    @pulumi.getter(name="containerGroupName")
    def container_group_name(self) -> Optional[str]:
        return pulumi.get(self, "container_group_name")

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def groups(self) -> Sequence['outputs.GetContainerGroupsGroupResult']:
        return pulumi.get(self, "groups")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def limit(self) -> Optional[int]:
        return pulumi.get(self, "limit")

    @property
    @pulumi.getter(name="nameRegex")
    def name_regex(self) -> Optional[str]:
        return pulumi.get(self, "name_regex")

    @property
    @pulumi.getter
    def names(self) -> Sequence[str]:
        return pulumi.get(self, "names")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="resourceGroupId")
    def resource_group_id(self) -> Optional[str]:
        return pulumi.get(self, "resource_group_id")

    @property
    @pulumi.getter
    def status(self) -> Optional[str]:
        return pulumi.get(self, "status")

    @property
    @pulumi.getter
    def tags(self) -> Optional[Mapping[str, str]]:
        return pulumi.get(self, "tags")

    @property
    @pulumi.getter(name="vswitchId")
    def vswitch_id(self) -> Optional[str]:
        return pulumi.get(self, "vswitch_id")

    @property
    @pulumi.getter(name="withEvent")
    def with_event(self) -> Optional[bool]:
        return pulumi.get(self, "with_event")

    @property
    @pulumi.getter(name="zoneId")
    def zone_id(self) -> Optional[str]:
        return pulumi.get(self, "zone_id")


class AwaitableGetContainerGroupsResult(GetContainerGroupsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetContainerGroupsResult(
            container_group_name=self.container_group_name,
            enable_details=self.enable_details,
            groups=self.groups,
            id=self.id,
            ids=self.ids,
            limit=self.limit,
            name_regex=self.name_regex,
            names=self.names,
            output_file=self.output_file,
            resource_group_id=self.resource_group_id,
            status=self.status,
            tags=self.tags,
            vswitch_id=self.vswitch_id,
            with_event=self.with_event,
            zone_id=self.zone_id)


def get_container_groups(container_group_name: Optional[str] = None,
                         enable_details: Optional[bool] = None,
                         ids: Optional[Sequence[str]] = None,
                         limit: Optional[int] = None,
                         name_regex: Optional[str] = None,
                         output_file: Optional[str] = None,
                         resource_group_id: Optional[str] = None,
                         status: Optional[str] = None,
                         tags: Optional[Mapping[str, str]] = None,
                         vswitch_id: Optional[str] = None,
                         with_event: Optional[bool] = None,
                         zone_id: Optional[str] = None,
                         opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetContainerGroupsResult:
    """
    This data source provides the Eci Container Groups of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.111.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.eci.get_container_groups(ids=["example_value"])
    pulumi.export("firstEciContainerGroupId", example.groups[0].id)
    ```


    :param str container_group_name: The name of ContainerGroup.
    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Container Group IDs.
    :param int limit: The maximum number of resources returned in the response. Default value is `20`. Maximum value: `20`. The number of returned results is no greater than the specified number.
    :param str name_regex: A regex string to filter results by Container Group name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The ID of the resource group to which the container group belongs. If you have not specified a resource group for the container group, it is added to the default resource group.
    :param str status: The status list. For more information, see the description of ContainerGroup arrays.
    :param str vswitch_id: The ID of the vSwitch. Currently, container groups can only be deployed in VPC networks.
    :param str zone_id: The ID of the zone where you want to deploy the container group. If no value is specified, the system assigns a zone to the container group. By default, no value is specified.
    """
    __args__ = dict()
    __args__['containerGroupName'] = container_group_name
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['limit'] = limit
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['vswitchId'] = vswitch_id
    __args__['withEvent'] = with_event
    __args__['zoneId'] = zone_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:eci/getContainerGroups:getContainerGroups', __args__, opts=opts, typ=GetContainerGroupsResult).value

    return AwaitableGetContainerGroupsResult(
        container_group_name=pulumi.get(__ret__, 'container_group_name'),
        enable_details=pulumi.get(__ret__, 'enable_details'),
        groups=pulumi.get(__ret__, 'groups'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        limit=pulumi.get(__ret__, 'limit'),
        name_regex=pulumi.get(__ret__, 'name_regex'),
        names=pulumi.get(__ret__, 'names'),
        output_file=pulumi.get(__ret__, 'output_file'),
        resource_group_id=pulumi.get(__ret__, 'resource_group_id'),
        status=pulumi.get(__ret__, 'status'),
        tags=pulumi.get(__ret__, 'tags'),
        vswitch_id=pulumi.get(__ret__, 'vswitch_id'),
        with_event=pulumi.get(__ret__, 'with_event'),
        zone_id=pulumi.get(__ret__, 'zone_id'))
def get_container_groups_output(container_group_name: Optional[pulumi.Input[Optional[str]]] = None,
                                enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                                ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                limit: Optional[pulumi.Input[Optional[int]]] = None,
                                name_regex: Optional[pulumi.Input[Optional[str]]] = None,
                                output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                resource_group_id: Optional[pulumi.Input[Optional[str]]] = None,
                                status: Optional[pulumi.Input[Optional[str]]] = None,
                                tags: Optional[pulumi.Input[Optional[Mapping[str, str]]]] = None,
                                vswitch_id: Optional[pulumi.Input[Optional[str]]] = None,
                                with_event: Optional[pulumi.Input[Optional[bool]]] = None,
                                zone_id: Optional[pulumi.Input[Optional[str]]] = None,
                                opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetContainerGroupsResult]:
    """
    This data source provides the Eci Container Groups of the current Alibaba Cloud user.

    > **NOTE:** Available in v1.111.0+.

    ## Example Usage

    Basic Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    example = alicloud.eci.get_container_groups(ids=["example_value"])
    pulumi.export("firstEciContainerGroupId", example.groups[0].id)
    ```


    :param str container_group_name: The name of ContainerGroup.
    :param bool enable_details: Default to `false`. Set it to `true` can output more details about resource attributes.
    :param Sequence[str] ids: A list of Container Group IDs.
    :param int limit: The maximum number of resources returned in the response. Default value is `20`. Maximum value: `20`. The number of returned results is no greater than the specified number.
    :param str name_regex: A regex string to filter results by Container Group name.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str resource_group_id: The ID of the resource group to which the container group belongs. If you have not specified a resource group for the container group, it is added to the default resource group.
    :param str status: The status list. For more information, see the description of ContainerGroup arrays.
    :param str vswitch_id: The ID of the vSwitch. Currently, container groups can only be deployed in VPC networks.
    :param str zone_id: The ID of the zone where you want to deploy the container group. If no value is specified, the system assigns a zone to the container group. By default, no value is specified.
    """
    __args__ = dict()
    __args__['containerGroupName'] = container_group_name
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['limit'] = limit
    __args__['nameRegex'] = name_regex
    __args__['outputFile'] = output_file
    __args__['resourceGroupId'] = resource_group_id
    __args__['status'] = status
    __args__['tags'] = tags
    __args__['vswitchId'] = vswitch_id
    __args__['withEvent'] = with_event
    __args__['zoneId'] = zone_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:eci/getContainerGroups:getContainerGroups', __args__, opts=opts, typ=GetContainerGroupsResult)
    return __ret__.apply(lambda __response__: GetContainerGroupsResult(
        container_group_name=pulumi.get(__response__, 'container_group_name'),
        enable_details=pulumi.get(__response__, 'enable_details'),
        groups=pulumi.get(__response__, 'groups'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        limit=pulumi.get(__response__, 'limit'),
        name_regex=pulumi.get(__response__, 'name_regex'),
        names=pulumi.get(__response__, 'names'),
        output_file=pulumi.get(__response__, 'output_file'),
        resource_group_id=pulumi.get(__response__, 'resource_group_id'),
        status=pulumi.get(__response__, 'status'),
        tags=pulumi.get(__response__, 'tags'),
        vswitch_id=pulumi.get(__response__, 'vswitch_id'),
        with_event=pulumi.get(__response__, 'with_event'),
        zone_id=pulumi.get(__response__, 'zone_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'DedicatedPropreHostEcsClassListArgs',
    'DedicatedPropreHostEcsClassListArgsDict',
]

MYPY = False

if not MYPY:
    class DedicatedPropreHostEcsClassListArgsDict(TypedDict):
        instance_type: pulumi.Input[str]
        """
        ECS specifications.
        """
        sys_disk_capacity: pulumi.Input[int]
        """
        System disk capacity.
        """
        sys_disk_type: pulumi.Input[str]
        """
        System disk type, value:
        - **cloud_essd**: the ESSD cloud disk.
        - **cloud_ssd**: SSD cloud disk.
        - **cloud_efficiency**: The ultra cloud disk.
        - **cloud_auto**: ESSD AutoPL cloud disk.
        """
        data_disk_performance_level: NotRequired[pulumi.Input[str]]
        """
        Data disk PL level.
        """
        disk_capacity: NotRequired[pulumi.Input[int]]
        """
        The capacity of the data disk.
        """
        disk_count: NotRequired[pulumi.Input[int]]
        """
        Number of mounted data disks.
        """
        disk_type: NotRequired[pulumi.Input[str]]
        """
        Data disk type, value range:
        - **cloud_essd**: the ESSD cloud disk.
        - **cloud_ssd**: SSD cloud disk.
        - **cloud_efficiency**: The ultra cloud disk.
        - **cloud_auto**: ESSD AutoPL cloud disk.
        """
        system_disk_performance_level: NotRequired[pulumi.Input[str]]
        """
        System disk PL level.
        """
elif False:
    DedicatedPropreHostEcsClassListArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class DedicatedPropreHostEcsClassListArgs:
    def __init__(__self__, *,
                 instance_type: pulumi.Input[str],
                 sys_disk_capacity: pulumi.Input[int],
                 sys_disk_type: pulumi.Input[str],
                 data_disk_performance_level: Optional[pulumi.Input[str]] = None,
                 disk_capacity: Optional[pulumi.Input[int]] = None,
                 disk_count: Optional[pulumi.Input[int]] = None,
                 disk_type: Optional[pulumi.Input[str]] = None,
                 system_disk_performance_level: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] instance_type: ECS specifications.
        :param pulumi.Input[int] sys_disk_capacity: System disk capacity.
        :param pulumi.Input[str] sys_disk_type: System disk type, value:
               - **cloud_essd**: the ESSD cloud disk.
               - **cloud_ssd**: SSD cloud disk.
               - **cloud_efficiency**: The ultra cloud disk.
               - **cloud_auto**: ESSD AutoPL cloud disk.
        :param pulumi.Input[str] data_disk_performance_level: Data disk PL level.
        :param pulumi.Input[int] disk_capacity: The capacity of the data disk.
        :param pulumi.Input[int] disk_count: Number of mounted data disks.
        :param pulumi.Input[str] disk_type: Data disk type, value range:
               - **cloud_essd**: the ESSD cloud disk.
               - **cloud_ssd**: SSD cloud disk.
               - **cloud_efficiency**: The ultra cloud disk.
               - **cloud_auto**: ESSD AutoPL cloud disk.
        :param pulumi.Input[str] system_disk_performance_level: System disk PL level.
        """
        pulumi.set(__self__, "instance_type", instance_type)
        pulumi.set(__self__, "sys_disk_capacity", sys_disk_capacity)
        pulumi.set(__self__, "sys_disk_type", sys_disk_type)
        if data_disk_performance_level is not None:
            pulumi.set(__self__, "data_disk_performance_level", data_disk_performance_level)
        if disk_capacity is not None:
            pulumi.set(__self__, "disk_capacity", disk_capacity)
        if disk_count is not None:
            pulumi.set(__self__, "disk_count", disk_count)
        if disk_type is not None:
            pulumi.set(__self__, "disk_type", disk_type)
        if system_disk_performance_level is not None:
            pulumi.set(__self__, "system_disk_performance_level", system_disk_performance_level)

    @property
    @pulumi.getter(name="instanceType")
    def instance_type(self) -> pulumi.Input[str]:
        """
        ECS specifications.
        """
        return pulumi.get(self, "instance_type")

    @instance_type.setter
    def instance_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "instance_type", value)

    @property
    @pulumi.getter(name="sysDiskCapacity")
    def sys_disk_capacity(self) -> pulumi.Input[int]:
        """
        System disk capacity.
        """
        return pulumi.get(self, "sys_disk_capacity")

    @sys_disk_capacity.setter
    def sys_disk_capacity(self, value: pulumi.Input[int]):
        pulumi.set(self, "sys_disk_capacity", value)

    @property
    @pulumi.getter(name="sysDiskType")
    def sys_disk_type(self) -> pulumi.Input[str]:
        """
        System disk type, value:
        - **cloud_essd**: the ESSD cloud disk.
        - **cloud_ssd**: SSD cloud disk.
        - **cloud_efficiency**: The ultra cloud disk.
        - **cloud_auto**: ESSD AutoPL cloud disk.
        """
        return pulumi.get(self, "sys_disk_type")

    @sys_disk_type.setter
    def sys_disk_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "sys_disk_type", value)

    @property
    @pulumi.getter(name="dataDiskPerformanceLevel")
    def data_disk_performance_level(self) -> Optional[pulumi.Input[str]]:
        """
        Data disk PL level.
        """
        return pulumi.get(self, "data_disk_performance_level")

    @data_disk_performance_level.setter
    def data_disk_performance_level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_disk_performance_level", value)

    @property
    @pulumi.getter(name="diskCapacity")
    def disk_capacity(self) -> Optional[pulumi.Input[int]]:
        """
        The capacity of the data disk.
        """
        return pulumi.get(self, "disk_capacity")

    @disk_capacity.setter
    def disk_capacity(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "disk_capacity", value)

    @property
    @pulumi.getter(name="diskCount")
    def disk_count(self) -> Optional[pulumi.Input[int]]:
        """
        Number of mounted data disks.
        """
        return pulumi.get(self, "disk_count")

    @disk_count.setter
    def disk_count(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "disk_count", value)

    @property
    @pulumi.getter(name="diskType")
    def disk_type(self) -> Optional[pulumi.Input[str]]:
        """
        Data disk type, value range:
        - **cloud_essd**: the ESSD cloud disk.
        - **cloud_ssd**: SSD cloud disk.
        - **cloud_efficiency**: The ultra cloud disk.
        - **cloud_auto**: ESSD AutoPL cloud disk.
        """
        return pulumi.get(self, "disk_type")

    @disk_type.setter
    def disk_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "disk_type", value)

    @property
    @pulumi.getter(name="systemDiskPerformanceLevel")
    def system_disk_performance_level(self) -> Optional[pulumi.Input[str]]:
        """
        System disk PL level.
        """
        return pulumi.get(self, "system_disk_performance_level")

    @system_disk_performance_level.setter
    def system_disk_performance_level(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "system_disk_performance_level", value)


